# server

HTTP server.

## Features

- Low latency
- Radix tree routing

## Installation

```shell
go get git.akyoto.dev/go/server
```

## Usage

```go
s := server.New()

// Static route
s.Get("/", func(ctx server.Context) error {
	return ctx.String("Hello")
})

// Parameter route
s.Get("/blog/:post", func(ctx server.Context) error {
	return ctx.String(ctx.Get("post"))
})

// Wildcard route
s.Get("/images/*file", func(ctx server.Context) error {
	return ctx.String(ctx.Get("file"))
})

s.Run(":8080")
```

## Tests

```
PASS: TestRouter
PASS: TestMiddleware
PASS: TestPanic
PASS: TestRun
PASS: TestUnavailablePort
coverage: 100.0% of statements
```

## Benchmarks

```
BenchmarkStatic/#00-12          34975490                33.63 ns/op            0 B/op          0 allocs/op
BenchmarkStatic/hello-12        26550235                44.20 ns/op            0 B/op          0 allocs/op
BenchmarkStatic/hello/world-12  20356144                59.08 ns/op            0 B/op          0 allocs/op
BenchmarkGitHub/gists/:id-12    21693214                54.80 ns/op            0 B/op          0 allocs/op
BenchmarkGitHub/repos/:a/:b-12  18118347                65.33 ns/op            0 B/op          0 allocs/op
```

## License

Please see the [license documentation](https://akyoto.dev/license).

## Copyright

© 2023 Eduard Urbach
